==> yaz-3.0.24.tgz: include/yaz/nmem.h <==
/*
 * Copyright (c) 1995-2007, Index Data
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Index Data nor the names of its contributors
 *       may be used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* $Id: nmem.h,v 1.26 2007-11-14 21:03:59 adam Exp $ */

/**
 * \file
 * \brief Header for Nibble Memory functions
 *
 * This is a simple and fairly wasteful little module for nibble memory
 * allocation. Eventually we'll put in something better.
 */
#ifndef NMEM_H
#define NMEM_H

#include <stddef.h>
#include <yaz/yconfig.h>

YAZ_BEGIN_CDECL

/** \brief NMEM handle (an opaque pointer to memory) */
typedef struct nmem_control *NMEM;

/** \brief releases memory associaged with an NMEM handle 
    \param n NMEM handle
*/
YAZ_EXPORT void nmem_reset(NMEM n);

/** \brief returns size in bytes of memory for NMEM handle
    \returns number of bytes
 */
YAZ_EXPORT int nmem_total(NMEM n);

/** \brief allocates string on NMEM handle (similar strdup) 
    \param mem HNEM handle
    \param src string
    \returns duplicated string
 */
YAZ_EXPORT char *nmem_strdup(NMEM mem, const char *src);
/** \brief allocates string on NMEM handle - allows NULL ptr buffer
    \param mem HNEM handle
    \param src string
    \returns duplicated string or NULL if src was NULL
 */
YAZ_EXPORT char *nmem_strdup_null(NMEM mem, const char *src);

/** \brief allocates string of certain size on NMEM handle
    \param mem NMEM handle
    \param src string
    \param n size of string
    \returns duplicated string (0 terminated)
 */
YAZ_EXPORT char *nmem_strdupn(NMEM mem, const char *src, size_t n);

/** \brief allocates sub strings out of string using certain delimitors
    \param nmem NMEM handle
    \param delim delimitor chars (splits on each char in there) 
    \param dstr string to be split
    \param darray result string array for each sub string
    \param num number of result strings
*/
YAZ_EXPORT void nmem_strsplit(NMEM nmem, const char *delim,
                              const char *dstr,
                              char ***darray, int *num);

/** \brief splits string into sub strings delimited by blanks
    \param nmem NMEM handle
    \param dstr string to be split
    \param darray result string array for each sub string
    \param num number of result strings
*/
YAZ_EXPORT void nmem_strsplit_blank(NMEM nmem, const char *dstr,
                                    char ***darray, int *num);

/** \brief allocates integer for NMEM
    \param nmem NMEM handle
    \param v integer value
    \returns pointer to created integer
*/
YAZ_EXPORT int *nmem_intdup(NMEM nmem, int v);

/** \brief transfers memory from one NMEM handle to another
    \param src source NMEM handle
    \param dst destination NMEM handle
 */
YAZ_EXPORT void nmem_transfer(NMEM dst, NMEM src);

/** \brief returns new NMEM handle 
    \returns NMEM handle
 */
YAZ_EXPORT NMEM nmem_create(void);

/** \brief destroys NMEM handle and memory associated with it
    \param n NMEM handle
 */
YAZ_EXPORT void nmem_destroy(NMEM n);

/** \brief allocates memory block on NMEM handle
    \param n NMEM handle
    \param size number of bytes to be allocated
    \returns pointer to allocated memory
 */
YAZ_EXPORT void *nmem_malloc(NMEM n, int size);

YAZ_EXPORT int yaz_errno(void);
YAZ_EXPORT void yaz_set_errno (int v);
YAZ_EXPORT void yaz_strerror(char *buf, int max);

YAZ_END_CDECL

#endif
/*
 * Local variables:
 * c-basic-offset: 4
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */

==> yaz-3.0.49p11.tgz: include/yaz/nmem.h <==
/* This file is part of the YAZ toolkit.
 * Copyright (C) 1995-2009 Index Data.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Index Data nor the names of its contributors
 *       may be used to endorse or promote products derived from this
 *       software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * \file
 * \brief Header for Nibble Memory functions
 *
 * This is a simple and fairly wasteful little module for nibble memory
 * allocation. Eventually we'll put in something better.
 */
#ifndef NMEM_H
#define NMEM_H

#include <stddef.h>
#include <yaz/yconfig.h>

YAZ_BEGIN_CDECL

/** \brief NMEM handle (an opaque pointer to memory) */
typedef struct nmem_control *NMEM;

/** \brief Set to 1 if YAZ BER integer is 64-bit ; 0 otherwise */
#define NMEM_64 0

#if NMEM_64
/** \brief BER/utility integer (64-bit or more) */
typedef long long int nmem_int_t;
/** \brief printf format for nmem_int_t type */
#define NMEM_INT_PRINTF "%lld"
#else
/** \brief BER/utility integer (32-bit on most platforms) */
typedef int nmem_int_t;
/** \brief printf format for nmem_int_t type */
#define NMEM_INT_PRINTF "%d"
#endif

/** \brief BER/utility boolean */
typedef int nmem_bool_t;

/** \brief releases memory associaged with an NMEM handle 
    \param n NMEM handle
*/
YAZ_EXPORT void nmem_reset(NMEM n);

/** \brief returns size in bytes of memory for NMEM handle
    \returns number of bytes
 */
YAZ_EXPORT int nmem_total(NMEM n);

/** \brief allocates string on NMEM handle (similar strdup) 
    \param mem HNEM handle
    \param src string
    \returns duplicated string
 */
YAZ_EXPORT char *nmem_strdup(NMEM mem, const char *src);
/** \brief allocates string on NMEM handle - allows NULL ptr buffer
    \param mem HNEM handle
    \param src string
    \returns duplicated string or NULL if src was NULL
 */
YAZ_EXPORT char *nmem_strdup_null(NMEM mem, const char *src);

/** \brief allocates string of certain size on NMEM handle
    \param mem NMEM handle
    \param src string
    \param n size of string
    \returns duplicated string (0 terminated)
 */
YAZ_EXPORT char *nmem_strdupn(NMEM mem, const char *src, size_t n);

/** \brief allocates sub strings out of string using certain delimitors
    \param nmem NMEM handle
    \param delim delimitor chars (splits on each char in there) 
    \param dstr string to be split
    \param darray result string array for each sub string
    \param num number of result strings
*/
YAZ_EXPORT void nmem_strsplit(NMEM nmem, const char *delim,
                              const char *dstr,
                              char ***darray, int *num);

/** \brief splits string into sub strings delimited by blanks
    \param nmem NMEM handle
    \param dstr string to be split
    \param darray result string array for each sub string
    \param num number of result strings
*/
YAZ_EXPORT void nmem_strsplit_blank(NMEM nmem, const char *dstr,
                                    char ***darray, int *num);

/** \brief allocates and sets integer for NMEM
    \param nmem NMEM handle
    \param v integer value
    \returns pointer to created integer
*/
YAZ_EXPORT nmem_int_t *nmem_intdup(NMEM nmem, nmem_int_t v);

/** \brief allocates and sets boolean for NMEM
    \param nmem NMEM handle
    \param v value (0=false, != 0 true)
    \returns pointer to created boolean
*/
YAZ_EXPORT nmem_bool_t *nmem_booldup(NMEM nmem, nmem_bool_t v);

/** \brief transfers memory from one NMEM handle to another
    \param src source NMEM handle
    \param dst destination NMEM handle
 */
YAZ_EXPORT void nmem_transfer(NMEM dst, NMEM src);

/** \brief returns new NMEM handle 
    \returns NMEM handle
 */
YAZ_EXPORT NMEM nmem_create(void);

/** \brief destroys NMEM handle and memory associated with it
    \param n NMEM handle
 */
YAZ_EXPORT void nmem_destroy(NMEM n);

/** \brief allocates memory block on NMEM handle
    \param n NMEM handle
    \param size number of bytes to be allocated
    \returns pointer to allocated memory
 */
YAZ_EXPORT void *nmem_malloc(NMEM n, int size);

YAZ_END_CDECL

#endif
/*
 * Local variables:
 * c-basic-offset: 4
 * c-file-style: "Stroustrup"
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */
